
local M = {}

-- initialize main menu
local pi2 = 2 * math.pi
local font = love.graphics.newFont(50)
local backgroundImage = love.graphics.newImage("images/menu_background.png")
local tiles, cursor = {}, {}
tiles.w, tiles.h = backgroundImage:getDimensions()
tiles.x, tiles.y = math.ceil(screen.w / tiles.w), math.ceil(screen.h / tiles.h)
tiles.z = math.max(tiles.w, tiles.h)
tiles.speed = 50
tiles.offset = 0
cursor.index = 1
cursor.max = 3
cursor.x = 85
cursor.w = 305
cursor.h = 50

function M.draw()
    
    -- initialize frame
    love.graphics.setColor(1, 1, 1, 1)
    
    -- draw scrolling background
    for x = 0, tiles.x do
        for y = 0, tiles.y do
            love.graphics.draw(backgroundImage, x * tiles.w - tiles.offset, y * tiles.h - tiles.offset)
        end
    end
    
    -- menu background
    love.graphics.setColor(1, 1, 1, 0.5)
    love.graphics.rectangle("fill", cursor.x - 5, 150, cursor.w + 10, 160, 5, 5)
    
    -- draw selection box
    love.graphics.setColor(0.5, 0.5, 1, 0.75)
    cursor.y = cursor.index * cursor.h + 105
    love.graphics.rectangle("fill", cursor.x, cursor.y, cursor.w, cursor.h, 25, 15)
    
    -- draw menu options
    love.graphics.setFont(font)
    love.graphics.setColor(0, 0, 0, 1)
    love.graphics.print("Crappy Game 2.0 - States", 12, 2)
    --~ love.graphics.print("States & Overlays", 12, 52)
    love.graphics.setColor(1, 1, 1, 1)
    love.graphics.print("Crappy Game 2.0 - States", 10, 0)
    --~ love.graphics.print("States & Overlays", 10, 50)
    love.graphics.print("New Game", 100, 150)
    love.graphics.print("Options", 100, 200)
    love.graphics.print("Quit", 100, 250)
    love.graphics.setFont(defaultFont)
end

function M.keypressed(key)
    if not player.active then
        -- do nothing
    elseif key == "down" then
        if cursor.index < cursor.max then
            cursor.index = cursor.index + 1
        else
            cursor.index = 1
        end
    elseif key == "up" then
        if cursor.index > 1 then
            cursor.index = cursor.index - 1
        else
            cursor.index = cursor.max
        end
    elseif key == "space" or key == "return" then
        if cursor.index == 1 then
            state.current = state.load
            state.load.pseudoLoad(1)
        elseif cursor.index == 2 then
            -- fixme: implement a couple overlays here...
        elseif cursor.index == 3 then
            love.graphics.captureScreenshot(getScreenshot)
            player.active = false
        end
    end
end

function M.update(dt)
    
    -- moving background
    tiles.offset = tiles.offset + dt * tiles.speed
    if tiles.offset > tiles.z then tiles.offset = tiles.offset - tiles.z end
    
    -- wait for screenshot to be available before quitting
    if not player.active and screen.screenshot then state.current = state.quit end
end

return M
